@@ -1,3 +1,12 @@
+fround <- function (x, digits) {
+    format (round (x, digits), nsmall=digits)
+}
+  
+pfround <- function (x, digits) {
+    print (fround (x, digits), quote=FALSE)
+}
+ 
+
 m <- NULL
 
 repath <- function(x) {
